==> qtools_profiler-2.2.x-dev.tar.gz: qtools_profiler/src/Form/ChannelsFilterForm.php <==
<?php

namespace Drupal\qtools_profiler\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\qtools_profiler\ReportService;

/**
 * Class ChannelsFilterForm.
 */
class ChannelsFilterForm extends FormBase {

  /**
   * Drupal\qtools_profiler\ReportService.
   *
   * @var \Drupal\qtools_profiler\ReportService
   */
  protected $reportService;

  /**
   * {@inheritdoc}
   */
  public function __construct(ReportService $reportService) {
    $this->reportService = $reportService;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('qtools_profiler.report')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'qtools_profiler_channels_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $dateFormat = 'Y-m-d';
    $timeFormat = 'H:i';
    $filters = $this->reportService->getChannelsFilters();

    $form['filters'] = [
      '#tree' => TRUE,
    ];
    $form['filters']['created'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Created'),
      '#date_date_format' => $dateFormat,
      '#date_time_format' => $timeFormat,
      '#default_value' => DrupalDateTime::createFromTimestamp($filters['created']),
    ];

    $form['filters']['last_accessed'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Last accessed'),
      '#date_date_format' => $dateFormat,
      '#date_time_format' => $timeFormat,
      '#default_value' => DrupalDateTime::createFromTimestamp($filters['last_accessed']),
    ];

    $form['filters']['cookie_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookie id'),
      '#size' => 128,
      '#default_value' => $filters['cookie_id'] ?? '',
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['apply'] = [
      '#type' => 'submit',
      '#value' => $this->t('Apply'),
      '#button_type' => 'primary',
      '#button_value' => 'apply',
    ];
    $form['actions']['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#button_value' => 'reset',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getTriggeringElement()['#button_value'] == 'reset') {
      $filters = [];
    }
    else {
      $filters = $form_state->getValue('filters');
      $filters['created'] = strtotime($filters['created']);
      $filters['last_accessed'] = strtotime($filters['last_accessed']);
    }
    $this->reportService->setChannelsFilters($filters);
  }

}

==> qtools_profiler-3.0.x-dev.tar.gz: qtools_profiler/src/Form/ChannelsFilterForm.php <==
<?php

namespace Drupal\qtools_profiler\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\qtools_profiler\ReportService;

/**
 * Class ChannelsFilterForm.
 */
class ChannelsFilterForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function __construct(
    protected ReportService $reportService) {
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get(ReportService::class)
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'qtools_profiler_channels_filter_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $dateFormat = 'Y-m-d';
    $timeFormat = 'H:i';
    $filters = $this->reportService->getChannelsFilters();

    $form['filters'] = [
      '#tree' => TRUE,
    ];
    $form['filters']['created'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Created'),
      '#date_date_format' => $dateFormat,
      '#date_time_format' => $timeFormat,
      '#default_value' => DrupalDateTime::createFromTimestamp($filters['created']),
    ];

    $form['filters']['last_accessed'] = [
      '#type' => 'datetime',
      '#title' => $this->t('Last accessed'),
      '#date_date_format' => $dateFormat,
      '#date_time_format' => $timeFormat,
      '#default_value' => DrupalDateTime::createFromTimestamp($filters['last_accessed']),
    ];

    $form['filters']['cookie_id'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Cookie id'),
      '#size' => 128,
      '#default_value' => $filters['cookie_id'] ?? '',
    ];

    $form['actions']['#type'] = 'actions';
    $form['actions']['apply'] = [
      '#type' => 'submit',
      '#value' => $this->t('Apply'),
      '#button_type' => 'primary',
      '#button_value' => 'apply',
    ];
    $form['actions']['reset'] = [
      '#type' => 'submit',
      '#value' => $this->t('Reset'),
      '#button_value' => 'reset',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if ($form_state->getTriggeringElement()['#button_value'] == 'reset') {
      $filters = [];
    }
    else {
      $filters = $form_state->getValue('filters');
      $filters['created'] = strtotime($filters['created']);
      $filters['last_accessed'] = strtotime($filters['last_accessed']);
    }
    $this->reportService->setChannelsFilters($filters);
  }

}
